@@ -70,8 +70,10 @@ def cached_as(sample, extra=None, timeout=None):
     # TODO: think of better way doing this.
     if isinstance(sample, (list, tuple)):
         return lambda func: func
-    if isinstance(sample, Model):
+    elif isinstance(sample, Model):
         queryset = sample.__class__.objects.inplace().filter(pk=sample.pk)
+    elif isinstance(sample, type) and issubclass(sample, Model):
+        queryset = sample.objects.all()
     else:
         queryset = sample
 
@@ -159,6 +161,8 @@ def _stringify_query():
             return sorted(obj)
         elif isinstance(obj, type):
             return '%s.%s' % (obj.__module__, obj.__name__)
+        elif hasattr(obj, '__uniq_key__'):
+            return (obj.__class__, obj.__uniq_key__())
         elif isinstance(obj, (datetime, date)):
             return str(obj)
         elif isinstance(obj, Constraint):
@@ -180,7 +184,13 @@ def _stringify_query():
             raise TypeError("Can't encode %s" % repr(obj))
 
     def stringify_query(query):
-        return json.dumps(query, default=encode_object, skipkeys=True, sort_keys=True, separators=(',',':'))
+        # HACK: Catch TypeError and reraise it as ValueError
+        #       since django hides it and behave weird when gets a TypeError in Queryset.iterator()
+        try:
+            return json.dumps(query, default=encode_object, skipkeys=True,
+                                     sort_keys=True, separators=(',',':'))
+        except TypeError as e:
+            raise ValueError(*e.args)
 
     return stringify_query
 stringify_query = _stringify_query()
