@@ -12,7 +12,7 @@ from django.conf import settings
 from cacheops.conf import redis_client
 
 
-__all__ = ('cache', 'cached', 'file_cache')
+__all__ = ('cache', 'cached', 'file_cache', 'CacheMiss')
 
 
 class CacheMiss(Exception):
@@ -33,8 +33,12 @@ class BaseCache(object):
                 # Calculating cache key based on func and arguments
                 md5 = md5_constructor()
                 md5.update('%s.%s' % (func.__module__, func.__name__))
+                # TODO: make it more civilized
                 if extra is not None:
-                    md5.update(str(extra))
+                    if isinstance(extra, (list, tuple)):
+                        md5.update(':'.join(map(str, extra)))
+                    else:
+                        md5.update(str(extra))
                 if args:
                     md5.update(repr(args))
                 if kwargs:
@@ -66,7 +70,7 @@ class RedisCache(BaseCache):
     def set(self, cache_key, data, timeout=None):
         pickled_data = pickle.dumps(data, -1)
         if timeout is not None:
-            self.conn.setex(cache_key, pickled_data, timeout)
+            self.conn.setex(cache_key, timeout, pickled_data)
         else:
             self.conn.set(cache_key, pickled_data)
 
@@ -74,7 +78,7 @@ cache = RedisCache(redis_client)
 cached = cache.cached
 
 
-FILE_CACHE_DIR = getattr(settings, 'FILE_CACHE_DIR', '/tmp/file_cache')
+FILE_CACHE_DIR = getattr(settings, 'FILE_CACHE_DIR', '/tmp/cacheops_file_cache')
 FILE_CACHE_TIMEOUT = getattr(settings, 'FILE_CACHE_TIMEOUT', 60*60*24*30)
 
 class FileCache(BaseCache):
